============================
Djblets 0.7.19 Release Notes
============================

**Release date**: October 10, 2013


Security updates
================

* :py:class:`JSONField` now corrects incorrectly stored contents in a
  safer way, to remove the risk of any exploits in a JSON payload.

  This is :cve:`2013-4409`, and was reported and patched by
  Frederik Braun.


General
=======

* Updated much of the codebase to be more compatible with Django 1.5
  and newer. The upcoming Djblets 0.8 releases will be geared more
  heavily toward Django 1.5 compatibility.


Packaging
=========

* Fixed building the static media for Djblets when using a Python
  interpreter other than the one named 'python' in the system path.

  Patch by Emmanuel Gil Peyrot.

* Djblets now requires django-pipeline 1.2.24. This version of
  Djblets does not work correctly with newer versions.


djblets.extensions
==================

* Extensions can now add additional middleware by setting
  :py:attr:`Extension.middleware`` to a list of middleware classes.

  Patch by Mark Côté.

* Updated :py:class:`ExtensionResource` to use the modern, type-checked,
  documented field style, and to add missing documentation.


djblets.util.templatetags.djblets_js
====================================

* The :py:func:`json_dumps` filter no longer defaults to indenting at all.
  Previously, it defaulted to 0, which did not indent code, but
  did preserve newlines.


djblets.webapi
==============

* :py:meth:`WebAPIError.with_message` no longer overrides the original
  message for all other instances of that error.

* Added :py:meth:`WebAPIError.with_overrides`, which allows overriding the
  message and HTTP headers.

* The webapi decorators now preserve and merge webapi-related
  information from other decorators, such as the lists of
  response errors and optional/required fields.


jquery.gravy
============

* The ``modalBox`` z-index has been increased from its previously
  low z-index, to prevent other UI elements from more easily
  popping up over it.

  Patch by Natasha Dalal.


Contributors
============

* Christian Hammond
* David Trowbridge
* Emmanuel Gil Peyrot
* Frederik Braun
* Mark Côté
* Natasha Dalal
